==> nextcloud-28.0.13rc1.zip: nextcloud/apps/serverinfo/l10n/uk.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Інформація про процесор недоступна",
    "Load average: {cpu} (last minute)" : "Середнє навантаження: {cpu} (за останню хвилину)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "Оперативна пам’ять: використовується {memUsageBytes} із {memTotalBytes}",
    "RAM info not available" : "Інформація про оперативну пам'ять недоступна",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "Файл підкачки: використовується {swapUsageBytes} із {swapTotalBytes}",
    "SWAP info not available" : "Інформація про обмін недоступна",
    "Copied!" : "Скопійовано!",
    "Not supported!" : "Не підтримується!",
    "Press ⌘-C to copy." : "Натисніть ⌘-C, щоб скопіювати.",
    "Press Ctrl-C to copy." : "Натисніть Ctrl-C, щоб скопіювати.",
    "System" : "Система",
    "Monitoring" : "Моніторинг",
    "Monitoring app with useful server information" : "Застосунок моніторингу з корисною інформацією про сервер",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Надає корисну інформацію про сервер, таку як навантаження ЦПУ, використання пам'яті, використання диску, кількість користувачів тощо.",
    "Operating System:" : "Операційна система:",
    "CPU:" : "ЦП:",
    "Unknown Processor" : "Невідомий процесор",
    "Memory:" : "Пам'ять:",
    "Server time:" : "Час сервера:",
    "Uptime:" : "Час роботи:",
    "Temperature" : "Температура",
    "Load" : "Навантаження",
    "Memory" : "Пам'ять",
    "Disk" : "Диск",
    "Mount:" : "Точка монтування:",
    "Filesystem:" : "Файлова система:",
    "Size:" : "Розмір:",
    "Available:" : "Доступно:",
    "Used:" : "Використовується:",
    "Files:" : "Файлів:",
    "Storages:" : "Сховищ:",
    "Free Space:" : "Вільно:",
    "Network" : "Мережа",
    "Hostname:" : "Ім'я хосту:",
    "Gateway:" : "Шлюз:",
    "Status:" : "Стан:",
    "Speed:" : "Швидкість:",
    "Duplex:" : "Двосторонній обмін:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Активні користувачі",
    "Last hour" : "За останню годину",
    "%s%% of all users" : "%s%% від усіх користувачів",
    "Last 24 Hours" : "За останні 24 години",
    "Last 7 Days" : "За останні 7 днів",
    "Last 30 Days" : "За останні 30 днів",
    "Shares" : "Ресурси спільного доступу",
    "Users:" : "Користувачів:",
    "Groups:" : "Груп:",
    "Links:" : "Посилань:",
    "Emails:" : "Ел. адрес:",
    "Federated sent:" : "Надіслано на сусідні сервери:",
    "Federated received:" : "Отримано від сусідніх серверів:",
    "Talk conversations:" : "Розмов Talk:",
    "PHP" : "PHP",
    "Version:" : "Версія:",
    "Memory limit:" : "Обмеження пам'яті:",
    "Max execution time:" : "Максимальний час виконання:",
    "Upload max size:" : "Макс. розмір завантаження:",
    "OPcache Revalidate Frequency:" : "Частота ревалідації OPcache:",
    "Extensions:" : "Розширення:",
    "Unable to list extensions" : "Не вдалося створити список розширень",
    "Show phpinfo" : "Показати phpinfo",
    "Database" : "База даних",
    "Type:" : "Тип:",
    "External monitoring tool" : "Моніторинг сторонніми засобами",
    "Use this end point to connect an external monitoring tool:" : "Точка доступу для під'єднання зовнішніх інструментів моніторингу:",
    "Copy" : "Копіювати",
    "Output in JSON" : "Вихідний звіт у форматі JSON",
    "Skip apps section (including apps section will send an external request to the app store)" : "Не показувати інформацію про застосунки (показ даних застосунків призведе до надсилання зовнішніх запитів до крамниці застосунків)",
    "Skip server update" : "Не показувати оновлення сервера",
    "To use an access token, please generate one then set it using the following command:" : "Щоби застосувати токен для доступу, спочатку зґенеруйте його, а потім встановіть за допомогою команди:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Потім передайте токен з додаванням заголовку \"NC-Token\" під час надсилання запиту за вказаною вище адресою URL.",
    "DNS:" : "DNS:",
    "Total users:" : "Разом користувачів:",
    "24 hours:" : "За добу:",
    "1 hour:" : "За останню годину:",
    "5 mins:" : "За останні 5 хв.:"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-29.0.2.zip: nextcloud/apps/serverinfo/l10n/uk.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Інформація про процесор недоступна",
    "Load average: {cpu} (last minute)" : "Середнє навантаження: {cpu} (за останню хвилину)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "Оперативна пам’ять: використовується {memUsageBytes} із {memTotalBytes}",
    "RAM info not available" : "Інформація про оперативну пам'ять недоступна",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "Файл підкачки: використовується {swapUsageBytes} із {swapTotalBytes}",
    "SWAP info not available" : "Інформація про обмін недоступна",
    "Copied!" : "Скопійовано!",
    "Not supported!" : "Не підтримується!",
    "Press ⌘-C to copy." : "Натисніть ⌘-C, щоб скопіювати.",
    "Press Ctrl-C to copy." : "Натисніть Ctrl-C, щоб скопіювати.",
    "System" : "Система",
    "Monitoring" : "Моніторинг",
    "Monitoring app with useful server information" : "Застосунок моніторингу з корисною інформацією про сервер",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Надає корисну інформацію про сервер, таку як навантаження ЦПУ, використання пам'яті, використання диску, кількість користувачів тощо.",
    "Operating System:" : "Операційна система:",
    "CPU:" : "ЦП:",
    "Unknown Processor" : "Невідомий процесор",
    "Memory:" : "Пам'ять:",
    "Server time:" : "Час сервера:",
    "Uptime:" : "Час роботи:",
    "Temperature" : "Температура",
    "Load" : "Навантаження",
    "Memory" : "Пам'ять",
    "Disk" : "Диск",
    "Mount:" : "Точка монтування:",
    "Filesystem:" : "Файлова система:",
    "Size:" : "Розмір:",
    "Available:" : "Доступно:",
    "Used:" : "Використовується:",
    "Files:" : "Файлів:",
    "Storages:" : "Сховищ:",
    "Free Space:" : "Вільно:",
    "Network" : "Мережа",
    "Hostname:" : "Ім'я хосту:",
    "Gateway:" : "Шлюз:",
    "Status:" : "Стан:",
    "Speed:" : "Швидкість:",
    "Duplex:" : "Двосторонній обмін:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Активні користувачі",
    "Total users:" : "Разом користувачів:",
    "24 hours:" : "За добу:",
    "1 hour:" : "За останню годину:",
    "5 mins:" : "За останні 5 хв.:",
    "Shares" : "Ресурси спільного доступу",
    "Users:" : "Користувачів:",
    "Groups:" : "Груп:",
    "Links:" : "Посилань:",
    "Emails:" : "Ел. адрес:",
    "Federated sent:" : "Надіслано на сусідні сервери:",
    "Federated received:" : "Отримано від сусідніх серверів:",
    "Talk conversations:" : "Розмов Talk:",
    "PHP" : "PHP",
    "Version:" : "Версія:",
    "Memory limit:" : "Обмеження пам'яті:",
    "Max execution time:" : "Максимальний час виконання:",
    "Upload max size:" : "Макс. розмір завантаження:",
    "OPcache Revalidate Frequency:" : "Частота ревалідації OPcache:",
    "Extensions:" : "Розширення:",
    "Unable to list extensions" : "Не вдалося створити список розширень",
    "Show phpinfo" : "Показати phpinfo",
    "Database" : "База даних",
    "Type:" : "Тип:",
    "External monitoring tool" : "Моніторинг сторонніми засобами",
    "Use this end point to connect an external monitoring tool:" : "Точка доступу для під'єднання зовнішніх інструментів моніторингу:",
    "Copy" : "Копіювати",
    "Output in JSON" : "Вихідний звіт у форматі JSON",
    "Skip app updates (including app updates will send an external request to the app store)" : "Пропускати оновлення застосунків (включно з оновленням застосунків, які надсилатимуть зовнішні запити до крамниці застосунків)",
    "Skip server update" : "Пропускати оновлення сервера",
    "To use an access token, please generate one then set it using the following command:" : "Щоби застосувати токен для доступу, спочатку зґенеруйте його, а потім встановіть за допомогою команди:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Потім передайте токен з додаванням заголовку \"NC-Token\" під час надсилання запиту за вказаною вище адресою URL.",
    "DNS:" : "DNS:"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
